{
    "$graph": [
        {
            "class": "CommandLineTool",
            "id": "#bwa_input_prepare.cwl",
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 1000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "kfdrc/bwa-bundle:dev"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "baseCommand": [],
            "arguments": [
                {
                    "position": 0,
                    "shellQuote": false,
                    "valueFrom": "samtools view -H $(inputs.input_bam.path) | grep ^@RG > rg.txt\nif [ $(inputs.input_bam.size) -gt $(inputs.max_siz) ]; then\n  bamtofastq tryoq=1 filename=$(inputs.input_bam.path) | split -dl 680000000 - reads-\n  ls reads-* | xargs -i mv {} {}.fq\n  rm $(inputs.input_bam.path)\nfi"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#bwa_input_prepare.cwl/bwa_input_prepare/input_bam"
                },
                {
                    "type": "int",
                    "default": 20000000000,
                    "id": "#bwa_input_prepare.cwl/bwa_input_prepare/max_siz"
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputBinding": {
                        "glob": "*.fq",
                        "outputEval": "${\n  if( inputs.input_bam.size < inputs.max_siz ) return [inputs.input_bam]\n  else return self\n}"
                    },
                    "id": "#bwa_input_prepare.cwl/bwa_input_prepare/output"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "rg.txt"
                    },
                    "id": "#bwa_input_prepare.cwl/bwa_input_prepare/rg"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "id": "#bwa_mem_split.cwl",
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 25000,
                    "coresMin": 17
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "images.sbgenomics.com/bogdang/bwa-kf-bundle:0.1.17"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "baseCommand": [],
            "arguments": [
                {
                    "position": 0,
                    "shellQuote": false,
                    "valueFrom": "if [ $(inputs.reads.nameext) = \".bam\" ]; then\n  CMD='/opt/biobambam2/2.0.87-release-20180301132713/x86_64-etch-linux-gnu/bin/bamtofastq tryoq=1 filename=$(inputs.reads.path)'\nelse\n  CMD='cat $(inputs.reads.path)'\nfi\n$CMD | bwa mem -K 100000000 -p -v 3 -t 15 -Y $(inputs.ref.path) -R '$(inputs.rg)' - | /opt/samblaster/samblaster -i /dev/stdin -o /dev/stdout | /opt/sambamba_0.6.3/sambamba_v0.6.3 view -t 17 -f bam -l 0 -S /dev/stdin | /opt/sambamba_0.6.3/sambamba_v0.6.3 sort -t 17 --natural-sort -m 15GiB --tmpdir ./ -o $(inputs.reads.nameroot).unsorted.bam -l 5 /dev/stdin\nrm $(inputs.reads.path)"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#bwa_mem_split.cwl/bwa_mem_split/reads"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".64.amb",
                        ".64.ann",
                        ".64.bwt",
                        ".64.pac",
                        ".64.sa",
                        ".64.alt",
                        "^.dict",
                        ".amb",
                        ".ann",
                        ".bwt",
                        ".pac",
                        ".sa"
                    ],
                    "id": "#bwa_mem_split.cwl/bwa_mem_split/ref"
                },
                {
                    "type": "string",
                    "id": "#bwa_mem_split.cwl/bwa_mem_split/rg"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*.bam"
                    },
                    "id": "#bwa_mem_split.cwl/bwa_mem_split/output"
                }
            ]
        },
        {
            "class": "ExpressionTool",
            "id": "#expression_checkcontamination.cwl",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "loadContents": true
                    },
                    "id": "#expression_checkcontamination.cwl/expression_checkcontamination/verifybamid_selfsm"
                }
            ],
            "outputs": [
                {
                    "type": "float",
                    "id": "#expression_checkcontamination.cwl/expression_checkcontamination/contamination"
                }
            ],
            "expression": "${ var lines=inputs.verifybamid_selfsm.contents.split('\\n'); for (var i=1; i<lines.length; i++){ var fields=lines[i].split('\\t'); if (fields.length != 19) {continue;} return {contamination: fields[6]/0.75}; } }"
        },
        {
            "class": "ExpressionTool",
            "id": "#expression_preparerg.cwl",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "loadContents": true
                    },
                    "id": "#expression_preparerg.cwl/expression_preparerg/rg"
                },
                {
                    "type": "string",
                    "id": "#expression_preparerg.cwl/expression_preparerg/sample"
                }
            ],
            "outputs": [
                {
                    "type": "string",
                    "id": "#expression_preparerg.cwl/expression_preparerg/rg_str"
                }
            ],
            "expression": "${ var arr = inputs.rg.contents.split('\\n')[0].split('\\t'); for (var i=1; i<arr.length; i++){ if (arr[i].startsWith('SM')){ arr[i] = 'SM:' + inputs.sample; } } return {rg_str: arr.join('\\\\t')}; }"
        },
        {
            "class": "CommandLineTool",
            "id": "#gatk_applybqsr.cwl",
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "kfdrc/gatk:4.0.3.0"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4500
                }
            ],
            "baseCommand": [
                "/gatk",
                "ApplyBQSR"
            ],
            "arguments": [
                {
                    "position": 1,
                    "shellQuote": false,
                    "valueFrom": "--java-options \"-Xms3000m -XX:+PrintFlagsFinal -XX:+PrintGCTimeStamps -XX:+PrintGCDateStamps -XX:+PrintGCDetails -Xloggc:gc_log.log -XX:GCTimeLimit=50 -XX:GCHeapFreeLimit=10\" --create-output-bam-md5 --add-output-sam-program-record -R $(inputs.reference.path) -I $(inputs.input_bam.path) --use-original-qualities -O $(inputs.input_bam.nameroot).aligned.duplicates_marked.recalibrated.bam -bqsr $(inputs.bqsr_report.path) --static-quantized-quals 10 --static-quantized-quals 20 --static-quantized-quals 30 -L $(inputs.sequence_interval.path)"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#gatk_applybqsr.cwl/gatk4_applybqsr/bqsr_report"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#gatk_applybqsr.cwl/gatk4_applybqsr/input_bam"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.dict",
                        ".fai"
                    ],
                    "id": "#gatk_applybqsr.cwl/gatk4_applybqsr/reference"
                },
                {
                    "type": "File",
                    "id": "#gatk_applybqsr.cwl/gatk4_applybqsr/sequence_interval"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*bam"
                    },
                    "secondaryFiles": [
                        "^.bai",
                        ".md5"
                    ],
                    "id": "#gatk_applybqsr.cwl/gatk4_applybqsr/recalibrated_bam"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "id": "#gatk_baserecalibrator.cwl",
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "kfdrc/gatk:4.0.3.0"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 8000
                }
            ],
            "baseCommand": [
                "/gatk",
                "BaseRecalibrator"
            ],
            "arguments": [
                {
                    "position": 0,
                    "shellQuote": false,
                    "valueFrom": "--java-options \"-Xms4000m -XX:GCTimeLimit=50 -XX:GCHeapFreeLimit=10 -XX:+PrintFlagsFinal -XX:+PrintGCTimeStamps -XX:+PrintGCDateStamps -XX:+PrintGCDetails -Xloggc:gc_log.log\" -R $(inputs.reference.path) -I $(inputs.input_bam.path) --use-original-qualities -O $(inputs.input_bam.nameroot).recal_data.csv -L $(inputs.sequence_interval.path)"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#gatk_baserecalibrator.cwl/gatkv4_baserecalibrator/input_bam"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File",
                        "inputBinding": {
                            "prefix": "--known-sites"
                        }
                    },
                    "inputBinding": {
                        "position": 1
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#gatk_baserecalibrator.cwl/gatkv4_baserecalibrator/knownsites"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.dict",
                        ".fai"
                    ],
                    "id": "#gatk_baserecalibrator.cwl/gatkv4_baserecalibrator/reference"
                },
                {
                    "type": "File",
                    "id": "#gatk_baserecalibrator.cwl/gatkv4_baserecalibrator/sequence_interval"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*.recal_data.csv"
                    },
                    "id": "#gatk_baserecalibrator.cwl/gatkv4_baserecalibrator/output"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "id": "#gatk_gatherbqsrreports.cwl",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "kfdrc/gatk:4.0.3.0"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 8000
                }
            ],
            "baseCommand": [
                "/gatk",
                "GatherBQSRReports"
            ],
            "arguments": [
                {
                    "position": 1,
                    "shellQuote": false,
                    "valueFrom": "--java-options \"-Xms3000m\" -O $(inputs.output_basename).GatherBqsrReports.recal_data.csv"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File",
                        "inputBinding": {
                            "prefix": "-I",
                            "separate": true
                        }
                    },
                    "id": "#gatk_gatherbqsrreports.cwl/gatk_gatherbqsrreports/input_brsq_reports"
                },
                {
                    "type": "string",
                    "id": "#gatk_gatherbqsrreports.cwl/gatk_gatherbqsrreports/output_basename"
                }
            ],
            "outputs": [
                {
                    "id": "#gatk_gatherbqsrreports.cwl/gatk_gatherbqsrreports/output",
                    "type": "File",
                    "outputBinding": {
                        "glob": "*.csv"
                    }
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "id": "#gatk_haplotypecaller.cwl",
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 10000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "kfdrc/gatk:4.beta.1-3.5"
                }
            ],
            "baseCommand": [
                "/gatk-launch",
                "--javaOptions",
                "-Xms2000m"
            ],
            "arguments": [
                {
                    "position": 1,
                    "shellQuote": false,
                    "valueFrom": "PrintReads -I $(inputs.input_bam.path) --interval_padding 500 -L $(inputs.interval_list.path) -O local.sharded.bam && java -XX:GCTimeLimit=50 -XX:GCHeapFreeLimit=10 -Xms8000m -jar /GenomeAnalysisTK.jar -T HaplotypeCaller -R $(inputs.reference.path) -o $(inputs.input_bam.nameroot).vcf.gz -I local.sharded.bam -L $(inputs.interval_list.path) -ERC GVCF --max_alternate_alleles 3 -variant_index_parameter 128000 -variant_index_type LINEAR -contamination $(inputs.contamination) --read_filter OverclippedRead"
                }
            ],
            "inputs": [
                {
                    "type": "float",
                    "id": "#gatk_haplotypecaller.cwl/gatk_haplotypecaller/contamination"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#gatk_haplotypecaller.cwl/gatk_haplotypecaller/input_bam"
                },
                {
                    "type": "File",
                    "id": "#gatk_haplotypecaller.cwl/gatk_haplotypecaller/interval_list"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.dict",
                        ".fai"
                    ],
                    "id": "#gatk_haplotypecaller.cwl/gatk_haplotypecaller/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*.vcf.gz"
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#gatk_haplotypecaller.cwl/gatk_haplotypecaller/output"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "id": "#picard_collectaggregationmetrics.cwl",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "kfdrc/picard-r:latest-dev"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 12000
                }
            ],
            "baseCommand": [
                "java",
                "-Xms5000m",
                "-jar",
                "/picard.jar",
                "CollectMultipleMetrics"
            ],
            "arguments": [
                {
                    "position": 1,
                    "shellQuote": false,
                    "valueFrom": "INPUT=$(inputs.input_bam.path) REFERENCE_SEQUENCE=$(inputs.reference.path) OUTPUT=$(inputs.input_bam.nameroot) ASSUME_SORTED=true PROGRAM=\"null\" PROGRAM=\"CollectAlignmentSummaryMetrics\"  PROGRAM=\"CollectInsertSizeMetrics\"  PROGRAM=\"CollectSequencingArtifactMetrics\"  PROGRAM=\"CollectGcBiasMetrics\"  PROGRAM=\"QualityScoreDistribution\"  METRIC_ACCUMULATION_LEVEL=\"null\"  METRIC_ACCUMULATION_LEVEL=\"SAMPLE\"  METRIC_ACCUMULATION_LEVEL=\"LIBRARY\""
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#picard_collectaggregationmetrics.cwl/picard_collectaggregationmetrics/input_bam"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.dict",
                        ".fai"
                    ],
                    "id": "#picard_collectaggregationmetrics.cwl/picard_collectaggregationmetrics/reference"
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputBinding": {
                        "glob": "$(inputs.input_bam.nameroot).*"
                    },
                    "id": "#picard_collectaggregationmetrics.cwl/picard_collectaggregationmetrics/output"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "id": "#picard_collectgvcfcallingmetrics.cwl",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 3000,
                    "coresMin": 16
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "kfdrc/picard:2.18.2-dev"
                }
            ],
            "baseCommand": [
                "java",
                "-Xms2000m",
                "-jar",
                "/picard.jar",
                "CollectVariantCallingMetrics"
            ],
            "arguments": [
                {
                    "position": 1,
                    "shellQuote": false,
                    "valueFrom": "INPUT=$(inputs.input_vcf.path) OUTPUT=$(inputs.final_gvcf_base_name) DBSNP=$(inputs.dbsnp_vcf.path) SEQUENCE_DICTIONARY=$(inputs.reference_dict.path) TARGET_INTERVALS=$(inputs.wgs_evaluation_interval_list.path) GVCF_INPUT=true THREAD_COUNT=16"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".idx"
                    ],
                    "id": "#picard_collectgvcfcallingmetrics.cwl/gatk_collectgvcfcallingmetrics/dbsnp_vcf"
                },
                {
                    "type": "string",
                    "id": "#picard_collectgvcfcallingmetrics.cwl/gatk_collectgvcfcallingmetrics/final_gvcf_base_name"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#picard_collectgvcfcallingmetrics.cwl/gatk_collectgvcfcallingmetrics/input_vcf"
                },
                {
                    "type": "File",
                    "id": "#picard_collectgvcfcallingmetrics.cwl/gatk_collectgvcfcallingmetrics/reference_dict"
                },
                {
                    "type": "File",
                    "id": "#picard_collectgvcfcallingmetrics.cwl/gatk_collectgvcfcallingmetrics/wgs_evaluation_interval_list"
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputBinding": {
                        "glob": "*_metrics"
                    },
                    "id": "#picard_collectgvcfcallingmetrics.cwl/gatk_collectgvcfcallingmetrics/output"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "id": "#picard_collectwgsmetrics.cwl",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 8000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "kfdrc/picard:2.18.2-dev"
                }
            ],
            "baseCommand": [
                "java",
                "-Xms2000m",
                "-jar",
                "/picard.jar",
                "CollectWgsMetrics"
            ],
            "arguments": [
                {
                    "position": 1,
                    "shellQuote": false,
                    "valueFrom": "INPUT=$(inputs.input_bam.path) VALIDATION_STRINGENCY=SILENT REFERENCE_SEQUENCE=$(inputs.reference.path) INCLUDE_BQ_HISTOGRAM=true INTERVALS=$(inputs.intervals.path) OUTPUT=$(inputs.input_bam.nameroot).wgs_metrics USE_FAST_ALGORITHM=true READ_LENGTH=250"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#picard_collectwgsmetrics.cwl/picard_collectwgsmetrics/input_bam"
                },
                {
                    "type": "File",
                    "id": "#picard_collectwgsmetrics.cwl/picard_collectwgsmetrics/intervals"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".fai"
                    ],
                    "id": "#picard_collectwgsmetrics.cwl/picard_collectwgsmetrics/reference"
                }
            ],
            "outputs": [
                {
                    "id": "#picard_collectwgsmetrics.cwl/picard_collectwgsmetrics/output",
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.input_bam.nameroot).wgs_metrics"
                    }
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "id": "#picard_gatherbamfiles.cwl",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "kfdrc/picard:2.18.2-dev"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 8000
                }
            ],
            "baseCommand": [],
            "arguments": [
                {
                    "position": 1,
                    "shellQuote": false,
                    "valueFrom": "rm_bams=\"${\n  var arr = [];\n  for (var i=0; i<inputs.input_bam.length; i++)\n      arr = arr.concat(inputs.input_bam[i].path)\n  return (arr.join(' '))\n}\"\ninput_bams=\"${\n  var arr = [];\n  for (var i=0; i<inputs.input_bam.length; i++)\n      arr = arr.concat(inputs.input_bam[i].path)\n  return (arr.join(' INPUT='))\n}\"\njava -Xms2000m -jar /picard.jar GatherBamFiles OUTPUT=$(inputs.output_bam_basename).bam INPUT=$input_bams CREATE_INDEX=true CREATE_MD5_FILE=true && rm $rm_bams"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#picard_gatherbamfiles.cwl/picard_gatherbamfiles/input_bam"
                },
                {
                    "type": "string",
                    "id": "#picard_gatherbamfiles.cwl/picard_gatherbamfiles/output_bam_basename"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*.bam"
                    },
                    "secondaryFiles": [
                        "^.bai",
                        ".md5"
                    ],
                    "id": "#picard_gatherbamfiles.cwl/picard_gatherbamfiles/output"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "id": "#picard_intervallisttools.cwl",
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "kfdrc/picard:2.18.2-dev"
                }
            ],
            "baseCommand": [
                "java",
                "-Xmx2000m",
                "-jar",
                "/picard.jar"
            ],
            "arguments": [
                {
                    "position": 1,
                    "shellQuote": false,
                    "valueFrom": "IntervalListTools SCATTER_COUNT=50 SUBDIVISION_MODE=BALANCING_WITHOUT_INTERVAL_SUBDIVISION_WITH_OVERFLOW UNIQUE=true SORT=true BREAK_BANDS_AT_MULTIPLES_OF=1000000 INPUT=$(inputs.interval_list.path) OUTPUT=$(runtime.outdir)"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#picard_intervallisttools.cwl/picard_intervallisttools/interval_list"
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputBinding": {
                        "glob": "temp*/*.interval_list"
                    },
                    "id": "#picard_intervallisttools.cwl/picard_intervallisttools/output"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "id": "#picard_mergevcfs.cwl",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 3000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "kfdrc/picard:2.18.2-dev"
                }
            ],
            "baseCommand": [
                "java",
                "-Xms2000m",
                "-jar",
                "/picard.jar",
                "MergeVcfs"
            ],
            "arguments": [
                {
                    "position": 1,
                    "shellQuote": false,
                    "valueFrom": "OUTPUT=$(inputs.output_vcf_basename).g.vcf.gz"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File",
                        "inputBinding": {
                            "prefix": "INPUT=",
                            "separate": false
                        }
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#picard_mergevcfs.cwl/picard_mergevcfs/input_vcf"
                },
                {
                    "type": "string",
                    "id": "#picard_mergevcfs.cwl/picard_mergevcfs/output_vcf_basename"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*.vcf.gz"
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#picard_mergevcfs.cwl/picard_mergevcfs/output"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "id": "#python_createsequencegroups.cwl",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "kfdrc/python:2.7.13"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "baseCommand": [
                "python",
                "-c"
            ],
            "arguments": [
                {
                    "position": 0,
                    "valueFrom": "def main():\n    with open(\"$(inputs.ref_dict.path)\", \"r\") as ref_dict_file:\n        sequence_tuple_list = []\n        longest_sequence = 0\n        for line in ref_dict_file:\n            if line.startswith(\"@SQ\"):\n                line_split = line.split(\"\\t\")\n                sequence_tuple_list.append((line_split[1].split(\"SN:\")[1], int(line_split[2].split(\"LN:\")[1])))\n        longest_sequence = sorted(sequence_tuple_list, key=lambda x: x[1], reverse=True)[0][1]\n    hg38_protection_tag = \":1+\"\n    tsv_string = sequence_tuple_list[0][0] + hg38_protection_tag\n    temp_size = sequence_tuple_list[0][1]\n    i = 0\n    for sequence_tuple in sequence_tuple_list[1:]:\n        if temp_size + sequence_tuple[1] <= longest_sequence:\n            temp_size += sequence_tuple[1]\n            tsv_string += \"\\n\" + sequence_tuple[0] + hg38_protection_tag\n        else:\n            i += 1\n            pad = \"{:0>2d}\".format(i)\n            tsv_file_name = \"sequence_grouping_\" + pad + \".intervals\"\n            with open(tsv_file_name, \"w\") as tsv_file:\n                tsv_file.write(tsv_string)\n                tsv_file.close()\n            tsv_string = sequence_tuple[0] + hg38_protection_tag\n            temp_size = sequence_tuple[1]\n    i += 1\n    pad = \"{:0>2d}\".format(i)\n    tsv_file_name = \"sequence_grouping_\" + pad + \".intervals\"\n    with open(tsv_file_name, \"w\") as tsv_file:\n        tsv_file.write(tsv_string)\n        tsv_file.close()\n\nif __name__ == \"__main__\":\n    main()"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#python_createsequencegroups.cwl/python_createsequencegroups/ref_dict"
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputBinding": {
                        "glob": "*.intervals"
                    },
                    "id": "#python_createsequencegroups.cwl/python_createsequencegroups/out_intervals"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "id": "#sambamba_merge.cwl",
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 2024,
                    "coresMin": 36
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "images.sbgenomics.com/bogdang/sambamba:0.6.3"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "baseCommand": [],
            "arguments": [
                {
                    "position": 0,
                    "shellQuote": false,
                    "valueFrom": "bams=\"${\n  var arr = [];\n  for (var i=0; i<inputs.bams.length; i++)\n    for (var j=0; j<inputs.bams[i].length; j++)\n      arr = arr.concat(inputs.bams[i][j].path)\n  return (arr.join(' '))\n}\"\n/opt/sambamba_0.6.3/sambamba_v0.6.3 merge -t 36 $(inputs.base_file_name).aligned.duplicates_marked.unsorted.bam $bams && rm $bams"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": {
                            "type": "array",
                            "items": "File"
                        }
                    },
                    "id": "#sambamba_merge.cwl/sambamba_merge/bams"
                },
                {
                    "type": "string",
                    "id": "#sambamba_merge.cwl/sambamba_merge/base_file_name"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*.bam"
                    },
                    "secondaryFiles": [
                        ".bai",
                        "^.bai"
                    ],
                    "format": "#sambamba_merge.cwl/sambamba_merge/BAM",
                    "id": "#sambamba_merge.cwl/sambamba_merge/merged_bam"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "id": "#sambamba_sort.cwl",
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 15000,
                    "coresMin": 36
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "images.sbgenomics.com/bogdang/sambamba:0.6.3"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "baseCommand": [],
            "arguments": [
                {
                    "position": 0,
                    "shellQuote": false,
                    "valueFrom": "/opt/sambamba_0.6.3/sambamba_v0.6.3 sort -t 36 -m 10G -o $(inputs.base_file_name).$(inputs.suffix).bam $(inputs.bam.path)\nmv $(inputs.base_file_name).$(inputs.suffix).bam.bai $(inputs.base_file_name).$(inputs.suffix).bai\nrm $(inputs.bam.path)"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#sambamba_sort.cwl/sambamba_sort/bam"
                },
                {
                    "type": "string",
                    "id": "#sambamba_sort.cwl/sambamba_sort/base_file_name"
                },
                {
                    "type": "string",
                    "default": "aligned.duplicates_marked.sorted",
                    "id": "#sambamba_sort.cwl/sambamba_sort/suffix"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*.bam"
                    },
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "format": "#sambamba_sort.cwl/sambamba_sort/BAM",
                    "id": "#sambamba_sort.cwl/sambamba_sort/sorted_bam"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "id": "#samtools_covert_to_cram.cwl",
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "kfdrc/samtools:1.8-dev"
                }
            ],
            "baseCommand": [
                "samtools",
                "view"
            ],
            "arguments": [
                {
                    "position": 1,
                    "shellQuote": false,
                    "valueFrom": "-C -T $(inputs.reference.path) -o $(inputs.input_bam.nameroot).cram $(inputs.input_bam.path) && samtools index $(inputs.input_bam.nameroot).cram"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#samtools_covert_to_cram.cwl/samtools_convert_to_cram/input_bam"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".fai"
                    ],
                    "id": "#samtools_covert_to_cram.cwl/samtools_convert_to_cram/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*.cram"
                    },
                    "secondaryFiles": [
                        ".crai"
                    ],
                    "id": "#samtools_covert_to_cram.cwl/samtools_convert_to_cram/output"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "id": "#samtools_split.cwl",
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "kfdrc/samtools:1.8-dev"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "baseCommand": [],
            "arguments": [
                {
                    "position": 0,
                    "shellQuote": false,
                    "valueFrom": "RG_NUM=`samtools view -H $(inputs.input_bam.path) | grep -c ^@RG`\nif [ $RG_NUM != 1 ]; then\n  samtools split -f '%!.bam' -@ 36 --reference $(inputs.reference.path) $(inputs.input_bam.path)\n  rm $(inputs.input_bam.path)\nfi"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#samtools_split.cwl/samtools_split/input_bam"
                },
                {
                    "type": "File",
                    "id": "#samtools_split.cwl/samtools_split/reference"
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputBinding": {
                        "glob": "*.bam",
                        "outputEval": "${\n  if (self.length == 0) return [inputs.input_bam]\n  else return self\n}"
                    },
                    "id": "#samtools_split.cwl/samtools_split/bam_files"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "id": "#verifybamid.cwl",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "kfdrc/verifybamid:1.0.2"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 5000,
                    "coresMin": 4
                }
            ],
            "baseCommand": [
                "/bin/VerifyBamID"
            ],
            "arguments": [
                {
                    "position": 1,
                    "shellQuote": false,
                    "valueFrom": "--Verbose --NumPC 4 --Output $(inputs.output_basename) --BamFile $(inputs.input_bam.path) --Reference $(inputs.ref_fasta.path) --UDPath $(inputs.contamination_sites_ud.path) --MeanPath $(inputs.contamination_sites_mu.path) --BedPath $(inputs.contamination_sites_bed.path) 1>/dev/null"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#verifybamid.cwl/verifybamid/contamination_sites_bed"
                },
                {
                    "type": "File",
                    "id": "#verifybamid.cwl/verifybamid/contamination_sites_mu"
                },
                {
                    "type": "File",
                    "id": "#verifybamid.cwl/verifybamid/contamination_sites_ud"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#verifybamid.cwl/verifybamid/input_bam"
                },
                {
                    "type": "string",
                    "id": "#verifybamid.cwl/verifybamid/output_basename"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".fai"
                    ],
                    "id": "#verifybamid.cwl/verifybamid/ref_fasta"
                }
            ],
            "outputs": [
                {
                    "id": "#verifybamid.cwl/verifybamid/output",
                    "type": "File",
                    "outputBinding": {
                        "glob": "*.selfSM"
                    }
                }
            ]
        },
        {
            "class": "Workflow",
            "id": "#main",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "id": "#main/biospecimen_name"
                },
                {
                    "type": "File",
                    "id": "#main/contamination_sites_bed"
                },
                {
                    "type": "File",
                    "id": "#main/contamination_sites_mu"
                },
                {
                    "type": "File",
                    "id": "#main/contamination_sites_ud"
                },
                {
                    "type": "File",
                    "id": "#main/dbsnp_vcf"
                },
                {
                    "type": "File",
                    "id": "#main/indexed_reference_fasta"
                },
                {
                    "type": "File",
                    "id": "#main/input_reads"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#main/knownsites"
                },
                {
                    "type": "string",
                    "id": "#main/output_basename"
                },
                {
                    "type": "File",
                    "id": "#main/reference_dict"
                },
                {
                    "type": "File",
                    "id": "#main/wgs_calling_interval_list"
                },
                {
                    "type": "File",
                    "id": "#main/wgs_coverage_interval_list"
                },
                {
                    "type": "File",
                    "id": "#main/wgs_evaluation_interval_list"
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/picard_collectaggregationmetrics/output",
                    "id": "#main/aggregation_metrics"
                },
                {
                    "type": "File",
                    "outputSource": "#main/gatk_gatherbqsrreports/output",
                    "id": "#main/bqsr_report"
                },
                {
                    "type": "File",
                    "outputSource": "#main/samtools_coverttocram/output",
                    "id": "#main/cram"
                },
                {
                    "type": "File",
                    "outputSource": "#main/picard_mergevcfs/output",
                    "id": "#main/gvcf"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/picard_collectgvcfcallingmetrics/output",
                    "id": "#main/gvcf_calling_metrics"
                },
                {
                    "type": "File",
                    "outputSource": "#main/verifybamid/output",
                    "id": "#main/verifybamid_output"
                },
                {
                    "type": "File",
                    "outputSource": "#main/picard_collectwgsmetrics/output",
                    "id": "#main/wgs_metrics"
                }
            ],
            "steps": [
                {
                    "run": "#kfdrc_bwamem_subwf.cwl",
                    "in": [
                        {
                            "source": "#main/indexed_reference_fasta",
                            "id": "#main/bwa_mem/indexed_reference_fasta"
                        },
                        {
                            "source": "#main/samtools_split/bam_files",
                            "id": "#main/bwa_mem/input_reads"
                        },
                        {
                            "source": "#main/biospecimen_name",
                            "id": "#main/bwa_mem/sample_name"
                        }
                    ],
                    "scatter": [
                        "#main/bwa_mem/input_reads"
                    ],
                    "out": [
                        "#main/bwa_mem/aligned_bams"
                    ],
                    "id": "#main/bwa_mem"
                },
                {
                    "run": "#expression_checkcontamination.cwl",
                    "in": [
                        {
                            "source": "#main/verifybamid/output",
                            "id": "#main/checkcontamination/verifybamid_selfsm"
                        }
                    ],
                    "out": [
                        "#main/checkcontamination/contamination"
                    ],
                    "id": "#main/checkcontamination"
                },
                {
                    "run": "#gatk_applybqsr.cwl",
                    "in": [
                        {
                            "source": "#main/gatk_gatherbqsrreports/output",
                            "id": "#main/gatk_applybqsr/bqsr_report"
                        },
                        {
                            "source": "#main/sambamba_sort/sorted_bam",
                            "id": "#main/gatk_applybqsr/input_bam"
                        },
                        {
                            "source": "#main/indexed_reference_fasta",
                            "id": "#main/gatk_applybqsr/reference"
                        },
                        {
                            "source": "#main/python_createsequencegroups/out_intervals",
                            "id": "#main/gatk_applybqsr/sequence_interval"
                        }
                    ],
                    "scatter": [
                        "#main/gatk_applybqsr/sequence_interval"
                    ],
                    "out": [
                        "#main/gatk_applybqsr/recalibrated_bam"
                    ],
                    "id": "#main/gatk_applybqsr"
                },
                {
                    "run": "#gatk_baserecalibrator.cwl",
                    "in": [
                        {
                            "source": "#main/sambamba_sort/sorted_bam",
                            "id": "#main/gatk_baserecalibrator/input_bam"
                        },
                        {
                            "source": "#main/knownsites",
                            "id": "#main/gatk_baserecalibrator/knownsites"
                        },
                        {
                            "source": "#main/indexed_reference_fasta",
                            "id": "#main/gatk_baserecalibrator/reference"
                        },
                        {
                            "source": "#main/python_createsequencegroups/out_intervals",
                            "id": "#main/gatk_baserecalibrator/sequence_interval"
                        }
                    ],
                    "scatter": [
                        "#main/gatk_baserecalibrator/sequence_interval"
                    ],
                    "out": [
                        "#main/gatk_baserecalibrator/output"
                    ],
                    "id": "#main/gatk_baserecalibrator"
                },
                {
                    "run": "#gatk_gatherbqsrreports.cwl",
                    "in": [
                        {
                            "source": "#main/gatk_baserecalibrator/output",
                            "id": "#main/gatk_gatherbqsrreports/input_brsq_reports"
                        },
                        {
                            "source": "#main/output_basename",
                            "id": "#main/gatk_gatherbqsrreports/output_basename"
                        }
                    ],
                    "out": [
                        "#main/gatk_gatherbqsrreports/output"
                    ],
                    "id": "#main/gatk_gatherbqsrreports"
                },
                {
                    "run": "#gatk_haplotypecaller.cwl",
                    "in": [
                        {
                            "source": "#main/checkcontamination/contamination",
                            "id": "#main/gatk_haplotypecaller/contamination"
                        },
                        {
                            "source": "#main/picard_gatherbamfiles/output",
                            "id": "#main/gatk_haplotypecaller/input_bam"
                        },
                        {
                            "source": "#main/picard_intervallisttools/output",
                            "id": "#main/gatk_haplotypecaller/interval_list"
                        },
                        {
                            "source": "#main/indexed_reference_fasta",
                            "id": "#main/gatk_haplotypecaller/reference"
                        }
                    ],
                    "scatter": [
                        "#main/gatk_haplotypecaller/interval_list"
                    ],
                    "out": [
                        "#main/gatk_haplotypecaller/output"
                    ],
                    "id": "#main/gatk_haplotypecaller"
                },
                {
                    "run": "#picard_collectaggregationmetrics.cwl",
                    "in": [
                        {
                            "source": "#main/picard_gatherbamfiles/output",
                            "id": "#main/picard_collectaggregationmetrics/input_bam"
                        },
                        {
                            "source": "#main/indexed_reference_fasta",
                            "id": "#main/picard_collectaggregationmetrics/reference"
                        }
                    ],
                    "out": [
                        "#main/picard_collectaggregationmetrics/output"
                    ],
                    "id": "#main/picard_collectaggregationmetrics"
                },
                {
                    "run": "#picard_collectgvcfcallingmetrics.cwl",
                    "in": [
                        {
                            "source": "#main/dbsnp_vcf",
                            "id": "#main/picard_collectgvcfcallingmetrics/dbsnp_vcf"
                        },
                        {
                            "source": "#main/output_basename",
                            "id": "#main/picard_collectgvcfcallingmetrics/final_gvcf_base_name"
                        },
                        {
                            "source": "#main/picard_mergevcfs/output",
                            "id": "#main/picard_collectgvcfcallingmetrics/input_vcf"
                        },
                        {
                            "source": "#main/reference_dict",
                            "id": "#main/picard_collectgvcfcallingmetrics/reference_dict"
                        },
                        {
                            "source": "#main/wgs_evaluation_interval_list",
                            "id": "#main/picard_collectgvcfcallingmetrics/wgs_evaluation_interval_list"
                        }
                    ],
                    "out": [
                        "#main/picard_collectgvcfcallingmetrics/output"
                    ],
                    "id": "#main/picard_collectgvcfcallingmetrics"
                },
                {
                    "run": "#picard_collectwgsmetrics.cwl",
                    "in": [
                        {
                            "source": "#main/picard_gatherbamfiles/output",
                            "id": "#main/picard_collectwgsmetrics/input_bam"
                        },
                        {
                            "source": "#main/wgs_coverage_interval_list",
                            "id": "#main/picard_collectwgsmetrics/intervals"
                        },
                        {
                            "source": "#main/indexed_reference_fasta",
                            "id": "#main/picard_collectwgsmetrics/reference"
                        }
                    ],
                    "out": [
                        "#main/picard_collectwgsmetrics/output"
                    ],
                    "id": "#main/picard_collectwgsmetrics"
                },
                {
                    "run": "#picard_gatherbamfiles.cwl",
                    "in": [
                        {
                            "source": "#main/gatk_applybqsr/recalibrated_bam",
                            "id": "#main/picard_gatherbamfiles/input_bam"
                        },
                        {
                            "source": "#main/output_basename",
                            "id": "#main/picard_gatherbamfiles/output_bam_basename"
                        }
                    ],
                    "out": [
                        "#main/picard_gatherbamfiles/output"
                    ],
                    "id": "#main/picard_gatherbamfiles"
                },
                {
                    "run": "#picard_intervallisttools.cwl",
                    "in": [
                        {
                            "source": "#main/wgs_calling_interval_list",
                            "id": "#main/picard_intervallisttools/interval_list"
                        }
                    ],
                    "out": [
                        "#main/picard_intervallisttools/output"
                    ],
                    "id": "#main/picard_intervallisttools"
                },
                {
                    "run": "#picard_mergevcfs.cwl",
                    "in": [
                        {
                            "source": "#main/gatk_haplotypecaller/output",
                            "id": "#main/picard_mergevcfs/input_vcf"
                        },
                        {
                            "source": "#main/output_basename",
                            "id": "#main/picard_mergevcfs/output_vcf_basename"
                        }
                    ],
                    "out": [
                        "#main/picard_mergevcfs/output"
                    ],
                    "id": "#main/picard_mergevcfs"
                },
                {
                    "run": "#python_createsequencegroups.cwl",
                    "in": [
                        {
                            "source": "#main/reference_dict",
                            "id": "#main/python_createsequencegroups/ref_dict"
                        }
                    ],
                    "out": [
                        "#main/python_createsequencegroups/out_intervals"
                    ],
                    "id": "#main/python_createsequencegroups"
                },
                {
                    "run": "#sambamba_merge.cwl",
                    "in": [
                        {
                            "source": "#main/bwa_mem/aligned_bams",
                            "id": "#main/sambamba_merge/bams"
                        },
                        {
                            "source": "#main/output_basename",
                            "id": "#main/sambamba_merge/base_file_name"
                        }
                    ],
                    "out": [
                        "#main/sambamba_merge/merged_bam"
                    ],
                    "id": "#main/sambamba_merge"
                },
                {
                    "run": "#sambamba_sort.cwl",
                    "in": [
                        {
                            "source": "#main/sambamba_merge/merged_bam",
                            "id": "#main/sambamba_sort/bam"
                        },
                        {
                            "source": "#main/output_basename",
                            "id": "#main/sambamba_sort/base_file_name"
                        }
                    ],
                    "out": [
                        "#main/sambamba_sort/sorted_bam"
                    ],
                    "id": "#main/sambamba_sort"
                },
                {
                    "run": "#samtools_covert_to_cram.cwl",
                    "in": [
                        {
                            "source": "#main/picard_gatherbamfiles/output",
                            "id": "#main/samtools_coverttocram/input_bam"
                        },
                        {
                            "source": "#main/indexed_reference_fasta",
                            "id": "#main/samtools_coverttocram/reference"
                        }
                    ],
                    "out": [
                        "#main/samtools_coverttocram/output"
                    ],
                    "id": "#main/samtools_coverttocram"
                },
                {
                    "run": "#samtools_split.cwl",
                    "in": [
                        {
                            "source": "#main/input_reads",
                            "id": "#main/samtools_split/input_bam"
                        },
                        {
                            "source": "#main/indexed_reference_fasta",
                            "id": "#main/samtools_split/reference"
                        }
                    ],
                    "out": [
                        "#main/samtools_split/bam_files"
                    ],
                    "id": "#main/samtools_split"
                },
                {
                    "run": "#verifybamid.cwl",
                    "in": [
                        {
                            "source": "#main/contamination_sites_bed",
                            "id": "#main/verifybamid/contamination_sites_bed"
                        },
                        {
                            "source": "#main/contamination_sites_mu",
                            "id": "#main/verifybamid/contamination_sites_mu"
                        },
                        {
                            "source": "#main/contamination_sites_ud",
                            "id": "#main/verifybamid/contamination_sites_ud"
                        },
                        {
                            "source": "#main/sambamba_sort/sorted_bam",
                            "id": "#main/verifybamid/input_bam"
                        },
                        {
                            "source": "#main/output_basename",
                            "id": "#main/verifybamid/output_basename"
                        },
                        {
                            "source": "#main/indexed_reference_fasta",
                            "id": "#main/verifybamid/ref_fasta"
                        }
                    ],
                    "out": [
                        "#main/verifybamid/output"
                    ],
                    "id": "#main/verifybamid"
                }
            ],
            "hints": [
                {
                    "class": "https://sevenbridges.comAWSInstanceType",
                    "value": "c4.8xlarge;ebs-gp2;850"
                },
                {
                    "class": "https://sevenbridges.commaxNumberOfParallelInstances",
                    "value": 4
                }
            ]
        },
        {
            "class": "Workflow",
            "id": "#kfdrc_bwamem_subwf.cwl",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#kfdrc_bwamem_subwf.cwl/bwa_mem_wf/indexed_reference_fasta"
                },
                {
                    "type": "File",
                    "id": "#kfdrc_bwamem_subwf.cwl/bwa_mem_wf/input_reads"
                },
                {
                    "type": "string",
                    "id": "#kfdrc_bwamem_subwf.cwl/bwa_mem_wf/sample_name"
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#kfdrc_bwamem_subwf.cwl/bwa_mem_wf/bwa_mem_split/output",
                    "id": "#kfdrc_bwamem_subwf.cwl/bwa_mem_wf/aligned_bams"
                }
            ],
            "steps": [
                {
                    "run": "#bwa_input_prepare.cwl",
                    "in": [
                        {
                            "source": "#kfdrc_bwamem_subwf.cwl/bwa_mem_wf/input_reads",
                            "id": "#kfdrc_bwamem_subwf.cwl/bwa_mem_wf/bwa_input_prepare/input_bam"
                        }
                    ],
                    "out": [
                        "#kfdrc_bwamem_subwf.cwl/bwa_mem_wf/bwa_input_prepare/output",
                        "#kfdrc_bwamem_subwf.cwl/bwa_mem_wf/bwa_input_prepare/rg"
                    ],
                    "id": "#kfdrc_bwamem_subwf.cwl/bwa_mem_wf/bwa_input_prepare"
                },
                {
                    "run": "#bwa_mem_split.cwl",
                    "in": [
                        {
                            "source": "#kfdrc_bwamem_subwf.cwl/bwa_mem_wf/bwa_input_prepare/output",
                            "id": "#kfdrc_bwamem_subwf.cwl/bwa_mem_wf/bwa_mem_split/reads"
                        },
                        {
                            "source": "#kfdrc_bwamem_subwf.cwl/bwa_mem_wf/indexed_reference_fasta",
                            "id": "#kfdrc_bwamem_subwf.cwl/bwa_mem_wf/bwa_mem_split/ref"
                        },
                        {
                            "source": "#kfdrc_bwamem_subwf.cwl/bwa_mem_wf/expression_updatergsample/rg_str",
                            "id": "#kfdrc_bwamem_subwf.cwl/bwa_mem_wf/bwa_mem_split/rg"
                        }
                    ],
                    "scatter": [
                        "#kfdrc_bwamem_subwf.cwl/bwa_mem_wf/bwa_mem_split/reads"
                    ],
                    "out": [
                        "#kfdrc_bwamem_subwf.cwl/bwa_mem_wf/bwa_mem_split/output"
                    ],
                    "id": "#kfdrc_bwamem_subwf.cwl/bwa_mem_wf/bwa_mem_split"
                },
                {
                    "run": "#expression_preparerg.cwl",
                    "in": [
                        {
                            "source": "#kfdrc_bwamem_subwf.cwl/bwa_mem_wf/bwa_input_prepare/rg",
                            "id": "#kfdrc_bwamem_subwf.cwl/bwa_mem_wf/expression_updatergsample/rg"
                        },
                        {
                            "source": "#kfdrc_bwamem_subwf.cwl/bwa_mem_wf/sample_name",
                            "id": "#kfdrc_bwamem_subwf.cwl/bwa_mem_wf/expression_updatergsample/sample"
                        }
                    ],
                    "out": [
                        "#kfdrc_bwamem_subwf.cwl/bwa_mem_wf/expression_updatergsample/rg_str"
                    ],
                    "id": "#kfdrc_bwamem_subwf.cwl/bwa_mem_wf/expression_updatergsample"
                }
            ]
        }
    ],
    "cwlVersion": "v1.0",
    "$namespaces": {
        "sbg": "https://sevenbridges.com"
    }
}
